import{P as r}from"./Passwordless.5b6366b4.js";import{N as a}from"./Navbar.0793caaa.js";import{d,b as i,c,e as t,H as p,q as _}from"./registerWidgets.08925b03.js";import{M as f}from"./member.4b2d1ae5.js";import"./CircularLoading.f7d06bfa.js";import"./lottie.028476ab.js";import"./icons.7d877907.js";import"./passwordlessManager.c2cb8449.js";import"./pubsub.7723f722.js";import"./logo.084e5d7c.js";import"./asyncComputed.fdfb8cdb.js";import"./gateway.95c71ee5.js";import"./activeRecord.030cb164.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="ddd8325b-a0b0-4860-a548-f60fa500f9fd",e._sentryDebugIdIdentifier="sentry-dbid-ddd8325b-a0b0-4860-a548-f60fa500f9fd")}catch{}})();const m={class:"login"},l=d({__name:"Login",setup(e){const o=p();async function s(n){await f.login(),o.push({name:"home"})}return(n,u)=>(i(),c("div",m,[t(a,{class:"nav"}),t(r,{class:"passwordless",onDone:s})]))}});const B=_(l,[["__scopeId","data-v-c9b2b4e6"]]);export{B as default};
//# sourceMappingURL=Login.89a26295.js.map
