import{v as s}from"./icons.7d877907.js";import{d as r,a as c,b as d,c as i,e as _,z as f,U as l,q as u}from"./registerWidgets.08925b03.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="8ca703a5-eef1-447f-bbf6-b4ddd840ae41",e._sentryDebugIdIdentifier="sentry-dbid-8ca703a5-eef1-447f-bbf6-b4ddd840ae41")}catch{}})();const b=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const a=c("icon");return d(),i("button",{class:"back-btn",onClick:n[0]||(n[0]=p=>t("exitFullscreenPreview"))},[_(a,{class:"icon",path:f(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),l(" Editor ")])}}});const v=u(b,[["__scopeId","data-v-eaeb3a6e"]]);export{v as B};
//# sourceMappingURL=BackButton.7f560b93.js.map
