import{d as r,r as c,o as i,a5 as l,b as f,c as u,N as b,af as y}from"./registerWidgets.08925b03.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="394b94c0-dd48-44fd-8166-c190cc5ba54d",e._sentryDebugIdIdentifier="sentry-dbid-394b94c0-dd48-44fd-8166-c190cc5ba54d")}catch{}})();const g=r({__name:"ActionButton",props:{action:null},emits:["next"],setup(e,{emit:n}){const o=e,s=c(null);i(()=>{s.value&&o.action.setElement(s.value),l.addAction(o.action)});const d=()=>n("next");return(m,t)=>(f(),u("button",{ref_key:"element",ref:s,class:"next-button",onClick:t[0]||(t[0]=a=>d()),onKeydown:t[1]||(t[1]=y(a=>d(),["enter"]))},b(e.action.name),545))}});export{g as _};
//# sourceMappingURL=ActionButton.vue_vue_type_script_setup_true_lang.8670e267.js.map
