import{L as o}from"./lottie.028476ab.js";import{d as t,r,o as s,b as d,c as i,x as c,B as _,q as l}from"./registerWidgets.08925b03.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="7284b892-a40a-4831-a892-aa65559e140b",a._sentryDebugIdIdentifier="sentry-dbid-7284b892-a40a-4831-a892-aa65559e140b")}catch{}})();const u={class:"container"},f=t({__name:"LoadingIndicator",setup(a){const e=r(null);return s(()=>{!e.value||o.loadAnimation({container:e.value,renderer:"svg",loop:!0,autoplay:!0,path:"/circularLoading.json"})}),(n,p)=>(d(),i("div",u,[c("div",{ref_key:"animation",ref:e,class:"animation"},null,512),_(n.$slots,"default",{},void 0,!0)]))}});const g=l(f,[["__scopeId","data-v-c30401d8"]]);export{g as L};
//# sourceMappingURL=LoadingIndicator.0a2d30b1.js.map
