import{q as t,b as s,c as d}from"./registerWidgets.08925b03.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="b1c59081-0cff-4dbd-a115-955169013cdb",e._sentryDebugIdIdentifier="sentry-dbid-b1c59081-0cff-4dbd-a115-955169013cdb")}catch{}})();const c={},o={class:"organization-settings"};function r(e,n){return s(),d("div",o,"Organization settings")}const f=t(c,[["render",r]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.1157839f.js.map
