import{S as d}from"./Sidebar.819b3cfb.js";import{N as m}from"./Navbar.0793caaa.js";import{E as p,F as l,G as u}from"./icons.7d877907.js";import{d as b,K as _,b as f,c as g,e as t,z as r,x as v,F as y,J as z,a as w,q as I}from"./registerWidgets.08925b03.js";import{a as h}from"./asyncComputed.fdfb8cdb.js";import"./gateway.95c71ee5.js";import{O}from"./organization.9603418c.js";import"./index.2d2fdeda.js";import"./Tooltip.9ea915c8.js";import"./logo.084e5d7c.js";import"./passwordlessManager.c2cb8449.js";import"./pubsub.7723f722.js";import"./activeRecord.030cb164.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="6babb34e-e20e-474d-82b6-205d21de0eff",e._sentryDebugIdIdentifier="sentry-dbid-6babb34e-e20e-474d-82b6-205d21de0eff")}catch{}})();const x={class:"organization"},k=b({__name:"Organization",setup(e){const n=z().params.organizationId,{result:a}=h(()=>O.get(n)),s=_(()=>a.value?[{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),i=[{name:"Organization",items:[{name:"Projects",icon:p,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(B,D)=>{const c=w("router-view");return f(),g(y,null,[t(m,{breadcrumb:r(s)},null,8,["breadcrumb"]),v("div",x,[t(d,{class:"sidebar",sections:r(i)},null,8,["sections"]),t(c)])],64)}}});const R=I(k,[["__scopeId","data-v-7eef90b7"]]);export{R as default};
//# sourceMappingURL=Organization.8a66b73d.js.map
