import{d as b,K as f,b as y,t as g,z as s,J as _}from"./registerWidgets.08925b03.js";import{a as w}from"./asyncComputed.fdfb8cdb.js";import"./gateway.95c71ee5.js";import{M as i}from"./member.4b2d1ae5.js";import"./index.2d2fdeda.js";import{C as I}from"./CrudView.730ee379.js";import"./passwordlessManager.c2cb8449.js";import"./pubsub.7723f722.js";import"./activeRecord.030cb164.js";import"./DropdownMenu.b53ce7fe.js";import"./Modal.b942b0e2.js";import"./LoadingIndicator.0a2d30b1.js";import"./lottie.028476ab.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="d1922e33-4c6f-4c8a-8a69-a8b1a410570b",e._sentryDebugIdIdentifier="sentry-dbid-d1922e33-4c6f-4c8a-8a69-a8b1a410570b")}catch{}})();const K=b({__name:"Members",setup(e){const o=_().params.organizationId,m=[{key:"email",label:"Email"}],l=async t=>{await i.create(o,t.email),p()},{loading:d,result:c,refetch:p}=w(()=>i.list(o)),u=f(()=>{var t,r;return{columns:[{name:"Email"},{name:"Role"}],rows:(r=(t=c.value)==null?void 0:t.map(n=>({key:n.email,cells:[{text:n.email,classes:["title","centered"]},{text:n.role,classes:["centered"]}]})))!=null?r:[]}});return(t,r)=>(y(),g(I,{"entity-name":"members",loading:s(d),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:s(u),"create-button-text":"Add members",fields:m,onCreate:l},null,8,["loading","table"]))}});export{K as default};
//# sourceMappingURL=Members.b857447f.js.map
