import{q as r,a,b as i,t as c,f as p,g as d,_,h as u,k as l,T as f,P as h,C as g,M as y,s as m,i as b,j as s,l as v,m as w,n as k}from"./registerWidgets.08925b03.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="23a8854a-6c9c-40c4-bda5-541158e3005e",e._sentryDebugIdIdentifier="sentry-dbid-23a8854a-6c9c-40c4-bda5-541158e3005e")}catch{}})();const I={};function x(e,t){const n=a("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const A=r(I,[["render",x]]),o=p({history:d("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.a5fe44e9.js"),["assets/Player.a5fe44e9.js","assets/index.a757f6bb.js","assets/registerWidgets.08925b03.js","assets/registerWidgets.448db7e9.css","assets/uuid.b8bcda35.js","assets/broker.7961a3f7.js","assets/passwordlessManager.c2cb8449.js","assets/pubsub.7723f722.js","assets/icons.7d877907.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.8670e267.js","assets/Passwordless.5b6366b4.js","assets/CircularLoading.f7d06bfa.js","assets/lottie.028476ab.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.86ac0c56.css","assets/executeJs.47243443.js","assets/PlayerNavbar.69c3e338.js","assets/PlayerNavbar.adff8b48.css","assets/WidgetsFrame.eb09d539.js","assets/colors.6a512de1.js","assets/WidgetsFrame.701a818b.css","assets/Modal.b942b0e2.js","assets/Modal.5aaf8eba.css","assets/executeJs.887e9a58.css","assets/broker.5f3abad8.css","assets/DashPlayer.f4fe4ac0.js","assets/runnerData.08bef8a6.js","assets/DashPlayer.ef4a798d.css","assets/asyncComputed.fdfb8cdb.js","assets/Player.20a058fa.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),D=()=>{const e=u({render:()=>l(A)});f.init(),e.use(o),e.use(h),e.mount("#app"),e.component("VSelect",g),e.component("Markdown",y),e.component("Message",m),b(e,o),s(e,v),s(e,w),s(e,k)};D();
//# sourceMappingURL=player.e1d60076.js.map
