import{q as n,b as o,c,x as r,d as _,a as d,t as i,w as l,e as u,U as f}from"./registerWidgets.08925b03.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ebb3d8c0-efa5-49ea-b110-16ae8aa68dc6",e._sentryDebugIdIdentifier="sentry-dbid-ebb3d8c0-efa5-49ea-b110-16ae8aa68dc6")}catch{}})();const p={},b={width:"12",height:"10",viewBox:"0 0 12 10",fill:"none",xmlns:"http://www.w3.org/2000/svg"},w=r("path",{d:"M2.8725 4.25L5.5575 1.5575L4.5 0.5L0 5L4.5 9.5L5.5575 8.4425L2.8725 5.75H12V4.25H2.8725Z",fill:"#6D7C93"},null,-1),k=[w];function B(e,t){return o(),c("svg",b,k)}const h=n(p,[["render",B]]),g=_({__name:"BackButton",props:{link:null},setup(e){return(t,a)=>{const s=d("router-link");return o(),i(s,{class:"link-button",to:e.link},{default:l(()=>[u(h),f(" Back ")]),_:1},8,["to"])}}});const m=n(g,[["__scopeId","data-v-56a12edc"]]);export{m as B};
//# sourceMappingURL=BackButton.793fdf19.js.map
